local Camera = require "camera"
local sti = require "sti"

function love.load()
	love.mouse.setVisible(false)
	mousex, mousey = love.mouse.getX(), love.mouse.getY()
	cam = Camera(mousex, mousey)
	cam:zoom(2)
    -- Grab window size
    windowWidth  = love.graphics.getWidth()
    windowHeight = love.graphics.getHeight()

    -- Set world meter size (in pixels)
    love.physics.setMeter(32)

    -- Load a map exported to Lua from Tiled
    map = sti.new("map01.lua", { "box2d" })

    -- Prepare physics world with horizontal and vertical gravity
    world = love.physics.newWorld(0, 0)

    -- Prepare collision objects
    map:box2d_init(world)

    -- Create a Custom Layer
    map:addCustomLayer("Object Layer 2", 3)

end

function love.update(dt)

	mdiffx, mdiffy = love.mouse.getX() - love.graphics.getWidth()/2, love.mouse.getY() - love.graphics.getHeight()/2

    map:update(dt)

		love.mouse.setPosition(love.graphics.getWidth()/2, love.graphics.getHeight()/2)

	cam:move(mdiffx, mdiffy)

end

function love.draw()
    -- Translation would normally be based on a player's x/y
    local translateX = 0
    local translateY = 0

    -- Draw Range culls unnecessary tiles
    map:setDrawRange(-translateX, -translateY, windowWidth, windowHeight)

	cam:attach()
    -- Draw the map and all objects within
    map:draw()

    -- Draw Collision Map (useful for debugging)
    love.graphics.setColor(255, 0, 0, 255)
    map:box2d_draw()
	cam:detach()

    -- Reset color
    love.graphics.setColor(255, 255, 255, 255)
end
